@@ -4,8 +4,8 @@
 
 ;; Author: Positron Solutions <contact@positron.solutions>
 ;; Keywords: convenience, outline
-;; Package-Version: 0.6.2
-;; Package-Revision: fda3cf6fae0c
+;; Package-Version: 20241229.1056
+;; Package-Revision: 84acdd7d74cf
 ;; Package-Requires: ((emacs "29.4") (hide-mode-line "1.0.3") (transient "0.7.2"))
 ;; Homepage: http://github.com/positron-solutions/moc
 
@@ -143,10 +143,10 @@ is valid value for the `fullscreen' frame parameter.
                        symbol)))
 
 (defcustom moc-face-remap-presets
-  '((bold . ((default :weight bold)))
-    (org-block-no-background . ((org-block :background reset
-                                           :extend reset))))
-   "Face remapping presets.
+  (let ((default-background (face-attribute 'default :background)))
+    `((bold . ((default :weight bold)))
+      (org-block-no-background . ((org-block :background ,default-background)))))
+  "Face remapping presets.
 Value is an alist.  Each entry should be a cons of SYMBOL PRESET.
 SYMBOL will be used to choose the PRESET.  PRESET is an ALIST where each
 element of PRESET is a cons of FACE SPECS where SPECS is one of the
@@ -394,7 +394,7 @@ Shocking."
   (let ((str (read-from-minibuffer
               prompt
               (when initial (number-to-string initial)) nil nil nil)))
-    (if (string-match-p "^-?[0-9]*$" str)
+    (if (string-match-p "^-?[0-9]+$" str)
         (string-to-number str)
       (user-error "Could not read number: %s" str))))
 
@@ -973,12 +973,7 @@ another window will likely leave something to be desired."
     (mapc (lambda (remap) (moc-face-remap remap t))
           moc-focus-default-remaps)
     (setq moc--focus-highlights highlights)
-    ;; TODO distinguish fully shadowed versus no highlights
-    (when highlights
-      (moc--focus-apply-highlights highlights))
     (setq moc--focus-occludes occludes)
-    (when occludes
-      (moc--focus-apply-occludes occludes))
 
     ;; First scale the text up to the size it will need to be after the
     ;; continuation strategy and horizontal & vertical centering.
@@ -1052,6 +1047,13 @@ another window will likely leave something to be desired."
         (add-hook 'window-state-change-functions #'moc--focus-refresh nil t)
         (goto-char 0)
         (insert (propertize "\n" 'face `(:height ,margin-lines)))
+
+        ;; TODO distinguish fully shadowed versus no highlights
+        (when highlights
+          (moc--focus-apply-highlights highlights))
+        (when occludes
+          (moc--focus-apply-occludes occludes))
+
         (setf (overlay-start scale-overlay) 2)
         (setf (overlay-end scale-overlay) (point-max))))
     (read-only-mode 1)))
@@ -1231,7 +1233,7 @@ OCCLUDES is a list of conses of BEG END to be occluded."
 
 (defun moc-focus-highlight-clear ()
   "Delete all highlights and occludes."
-  (interactive)
+  (interactive nil moc-focus-mode)
   (moc--focus-assert-mode)
   (unless (or moc--focus-highlights
               moc--focus-occludes)
@@ -1243,21 +1245,17 @@ OCCLUDES is a list of conses of BEG END to be occluded."
   (mapc #'delete-overlay moc--focus-occluding-overlays)
   (setq moc--focus-occluding-overlays nil))
 
-(put 'moc-focus-highlight-clear 'mode 'moc-focus-mode)
-
 (defun moc-focus-quit ()
   "Fullscreen quit command."
-  (interactive)
+  (interactive nil moc-focus-mode)
   (if-let* ((buffer (get-buffer "*MoC Focus*")))
       (kill-buffer buffer)
     (user-error "No MoC buffer found")))
 
-(put 'moc-focus-quit 'mode 'moc-focus-mode)
-
 (defun moc-focus-highlight (beg end)
   "Highlight region between BEG and END.
 The shadow face will be applied to remaining unhighlighted regions."
-  (interactive "r")
+  (interactive "r" moc-focus-mode)
   (moc--focus-assert-mode)
   (moc--focus-highlight beg end)
   (moc--focus-un-occlude beg end)
@@ -1267,13 +1265,11 @@ The shadow face will be applied to remaining unhighlighted regions."
   (moc--focus-apply-highlights moc--focus-highlights)
   (moc--focus-apply-occludes moc--focus-occludes))
 
-(put 'moc-focus-highlight 'mode 'moc-focus-mode)
-
 (defun moc-focus-occlude (beg end)
   "Occlude region between BEG and END.
 This overrides any highlights or shadows.  Use un-highlight or highlight
 to make occluded regions visible again."
-  (interactive "r")
+  (interactive "r" moc-focus-mode)
   (moc--focus-assert-mode)
   (moc--focus-occlude beg end)
   ;; unnecessary to deactivate the mark when called any other way
@@ -1281,12 +1277,10 @@ to make occluded regions visible again."
     (deactivate-mark))
   (moc--focus-apply-occludes moc--focus-occludes))
 
-(put 'moc-focus-occlude 'mode 'moc-focus-mode)
-
 (defun moc-focus-un-highlight (beg end)
   "Remove highlight in region between BEG and END.
 The shadow face will be added to the region between BEG and END."
-  (interactive "r")
+  (interactive "r" moc-focus-mode)
   (moc--focus-assert-mode)
   (unless moc--focus-highlights
     (user-error "No highlights to un-highlight"))
@@ -1298,12 +1292,10 @@ The shadow face will be added to the region between BEG and END."
   (moc--focus-apply-highlights moc--focus-highlights)
   (moc--focus-apply-occludes moc--focus-occludes))
 
-(put 'moc-focus-un-highlight 'mode 'moc-focus-mode)
-
 (defun moc-focus-toggle-overlays ()
   "Toggle overlays from the source.
 This enables independent demonstration of the effect of source overlays."
-  (interactive)
+  (interactive nil moc-focus-mode)
   (moc--focus-assert-mode)
   (if moc--focus-overlays
       (progn (mapc #'delete-overlay
@@ -1315,23 +1307,21 @@ This enables independent demonstration of the effect of source overlays."
      ;; line without stretching the background for that line, let me know 😉!
      moc--focus-overlay-specs 1)))
 
-(put 'moc-focus-toggle-overlays 'mode 'moc-focus-mode)
-
 (defun moc-focus-toggle-invisibility ()
   "Toggle the `buffer-invisibility-spec'.
 This enables seeing the effects of the `invisible' text property."
-  (interactive)
+  (interactive nil moc-focus-mode)
   (moc--focus-assert-mode)
   (if buffer-invisibility-spec
-      (setq buffer-invisibility-spec nil)
+      (progn (setq buffer-invisibility-spec nil)
+             (redraw-display))
     (setq buffer-invisibility-spec
-          moc--focus-invisibilty-spec)))
-
-(put 'moc-focus-toggle-invisibility 'mode 'moc-focus-mode)
+          moc--focus-invisibilty-spec)
+    (redraw-display)))
 
 (defun moc-focus-kill-ring-save ()
   "Save the focused text and highlights to a playback expression."
-  (interactive)
+  (interactive nil moc-focus-mode)
   (moc--focus-assert-mode)
   (let ((expression
          `(moc-focus
@@ -1339,16 +1329,21 @@ This enables seeing the effects of the `invisible' text property."
            :continuation ',moc--focus-continuation
            :highlights ',moc--focus-highlights
            :occludes ',moc--focus-occludes
-           :invisibility-spec ',moc--focus-invisibilty-spec
+           :invisibility-spec ',buffer-invisibility-spec
            :overlays ',moc--focus-overlay-specs
            :text ,moc--focus-cleaned-text)))
     (kill-new (prin1-to-string expression)))
   (message "saved focus to kill ring."))
 
-(put 'moc-focus-kill-ring-save 'mode 'moc-focus-mode)
-
 ;; ** Focus Extraction & Pre-Processing
 
+(defun moc--focus-pre-clean-input (buffer)
+  "Remove anything troublesome to process."
+  (with-current-buffer buffer
+    (let ((inhibit-read-only t))
+      (remove-text-properties (point-min) (point-max)
+                              '(read-only nil)))))
+
 (defun moc--focus-copy-overlays (buffer beg end)
   "Copy buffers between BEG and END to BUFFER.
 It is assumed that BUFFER was offset by BEG."
@@ -1409,7 +1404,8 @@ newlines."
 
 (defun moc--focus-trim-whitespace (buffer)
   "Clean unwanted whitespace in BUFFER."
-  (let ((old (current-buffer)))
+  (let ((old (current-buffer))
+        (inhibit-field-text-motion t))
     (set-buffer buffer)
     (setq buffer-invisibility-spec nil)
     ;; Trim whitespace lines at beginning and end
@@ -1466,7 +1462,7 @@ text we have is likely incomplete out of context."
           (lambda (prop-name)
             (when-let* ((prop (plist-get (car interval) prop-name)))
               (put-text-property begin end prop-name prop clean-string)))
-          '(face font-lock-face button invisible display))))
+          '(face font-lock-face button invisible display category))))
      dirty-props)
     clean-string))
 
@@ -1557,25 +1553,32 @@ Found: %s  Required:  %s"
   "Focus selected region.
 ARGS contains the following keys:
 
-- :continuation 🚧 This option is experimental.  Right now it contains enough
-  information for the downstream `mc-focus-playback' to decide a continuation
-  strategy and to
+- :continuation 🚧 This option is experimental.  Right now it contains
+  enough information for the downstream `mc-focus-playback' to decide a
+  continuation strategy and to
+
 - :overlays is a list of (BEG END . PROPS) where PROPS is returned by
-  `overlay-properties'.  Each element of the list is used to rehydrate an
-  overlay to recreate the capture source.
+  `overlay-properties'.  Each element of the list is used to rehydrate
+  an overlay to recreate the capture source.
+
 - :invisibility-spec propagates the buffer's invisibility spec
+
 - :highlights a list of conses of BEG END that will be highlighted
+
 - :occludes a list of conses of BEG END that will be occluded
+
 - :text The text to be displayed.
-- :version Serialization and playback are coupled.  When versions don't match
-  or are missing, a warning will be displayed."
+
+- :version Serialization and playback are coupled.  When versions don't
+  match or are missing, a warning will be displayed."
   (interactive
    (if (region-active-p)
        (save-excursion
-         (when-let ((old (get-buffer " *MoC Processing")))
+         (when-let ((old (get-buffer " *MoC Processing*")))
+           (kill-buffer old)
            (display-warning '(mc mc-focus mc-focus-playback)
-                            (format  "Killing stale processing buffer %s"
-                                     " *MoC Processing")
+                            (format  "Killing stale processing buffer %S"
+                                     " *MoC Processing*")
                             :warning))
          (let* ((buffer (get-buffer-create " *MoC Processing*"))
                 (rect (when rectangle-mark-mode
@@ -1585,13 +1588,14 @@ ARGS contains the following keys:
                 (end (region-end))
                 before)
            (when (string= (buffer-name) " *MoC Processing*")
-             (user-error "Cannot process the processing buffer: %s"
+             (user-error "Cannot process the processing buffer: %S"
                          (buffer-name)))
            (goto-char beg)
            (beginning-of-line)
            (setq before (point))
            (copy-to-buffer buffer beg end)
 
+           (moc--focus-pre-clean-input buffer)
            (moc--focus-copy-overlays buffer beg end)
            (moc--focus-pad buffer (- beg before))
            (moc--focus-trim-rect buffer rect before)
@@ -1642,15 +1646,13 @@ Used in suffix command."
 When in a focus buffer, likely the user does not want to ever have a
 fully visible cursor.  This command directly toggles hidden and subtle
 instead."
-  (interactive)
+  (interactive nil moc-focus-mode)
   (if moc-subtle-cursor-mode
       (moc-subtle-cursor-mode -1)
     (moc-subtle-cursor-mode 1))
   (unless moc-subtle-cursor-mode
     (moc-hide-cursor-mode 1)))
 
-(put 'moc--focus-cursor-toggle 'mode 'moc-focus-mode)
-
 (defun moc--focus-dispatch-overlays ()
   "Describe state of overlays.
 Used in suffix."
